==> ejc-cost-api-3.0.0-20201207.085343-3-sources.jar: com/ejianc/business/cost/vo/ShareVO.java <==
package com.ejianc.business.cost.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 成本分摊
 * 
 * @author generator
 * 
 */
public class ShareVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String taxFlag; // 是否含税 0-是，1-否
    private java.lang.Long projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.String materialCost; // 物资成本 0-出库入成本，1-物资合同结算入成本
    private java.lang.String period; // 期间
    private java.lang.String lastPeriod; // 上期核算期间
    private java.math.BigDecimal lastCostMny; // 上期分摊成本
    private java.math.BigDecimal sumCostMny; // 累计分摊成本
    private java.math.BigDecimal costMny; // 本期分摊成本
    private java.math.BigDecimal unCostMny; // 待分摊成本
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String createUserName; // 创建人名称
    

    /**
     * 是否含税 0-是，1-否
     */
    public java.lang.String getTaxFlag() {
        return taxFlag;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public void setTaxFlag(java.lang.String taxFlag) {
        this.taxFlag = taxFlag;
    }
    /**
     * 项目
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public java.lang.String getMaterialCost() {
        return materialCost;
    }

    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public void setMaterialCost(java.lang.String materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 期间
     */
    public java.lang.String getPeriod() {
        return period;
    }

    /**
     * 期间
     */
    public void setPeriod(java.lang.String period) {
        this.period = period;
    }
    /**
     * 上期核算期间
     */
    public java.lang.String getLastPeriod() {
        return lastPeriod;
    }

    /**
     * 上期核算期间
     */
    public void setLastPeriod(java.lang.String lastPeriod) {
        this.lastPeriod = lastPeriod;
    }
    /**
     * 上期分摊成本
     */
    public java.math.BigDecimal getLastCostMny() {
        return lastCostMny;
    }

    /**
     * 上期分摊成本
     */
    public void setLastCostMny(java.math.BigDecimal lastCostMny) {
        this.lastCostMny = lastCostMny;
    }
    /**
     * 累计分摊成本
     */
    public java.math.BigDecimal getSumCostMny() {
        return sumCostMny;
    }

    /**
     * 累计分摊成本
     */
    public void setSumCostMny(java.math.BigDecimal sumCostMny) {
        this.sumCostMny = sumCostMny;
    }
    /**
     * 本期分摊成本
     */
    public java.math.BigDecimal getCostMny() {
        return costMny;
    }

    /**
     * 本期分摊成本
     */
    public void setCostMny(java.math.BigDecimal costMny) {
        this.costMny = costMny;
    }
    /**
     * 待分摊成本
     */
    public java.math.BigDecimal getUnCostMny() {
        return unCostMny;
    }

    /**
     * 待分摊成本
     */
    public void setUnCostMny(java.math.BigDecimal unCostMny) {
        this.unCostMny = unCostMny;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}

==> ejc-cost-api-3.0.0-20201229.100530-42-sources.jar: com/ejianc/business/cost/vo/ShareVO.java <==
package com.ejianc.business.cost.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;


/**
 * 成本分摊
 * 
 * @author generator
 * 
 */
public class ShareVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String taxFlag; // 是否含税 0-是，1-否
    private java.lang.Long projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.String materialCost; // 物资成本 0-出库入成本，1-物资合同结算入成本
    private java.lang.String period; // 期间
    private java.lang.String lastPeriod; // 上期核算期间
    private java.math.BigDecimal lastCostMny; // 上期分摊成本
    private java.math.BigDecimal sumCostMny; // 累计分摊成本
    private java.math.BigDecimal costMny; // 本期分摊成本
    private java.math.BigDecimal unCostMny; // 待分摊成本
    private java.lang.String memo; // 备注
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String createUserName; // 创建人名称
    private java.lang.String endDay; // 当前期间最后一天


    // 费用项明细子表
    private List<ShareDetailVO> shareDetail = new ArrayList<ShareDetailVO>();

    public List<ShareDetailVO> getShareDetail() {
        return shareDetail;
    }

    public void setShareDetail(List<ShareDetailVO> shareDetail) {
        this.shareDetail = shareDetail;
    }

    public String getEndDay() {
        return endDay;
    }

    public void setEndDay(String endDay) {
        this.endDay = endDay;
    }



    /**
     * 是否含税 0-是，1-否
     */
    public java.lang.String getTaxFlag() {
        return taxFlag;
    }

    /**
     * 是否含税 0-是，1-否
     */
    public void setTaxFlag(java.lang.String taxFlag) {
        this.taxFlag = taxFlag;
    }
    /**
     * 项目
     */
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public java.lang.String getMaterialCost() {
        return materialCost;
    }

    /**
     * 物资成本 0-出库入成本，1-物资合同结算入成本
     */
    public void setMaterialCost(java.lang.String materialCost) {
        this.materialCost = materialCost;
    }
    /**
     * 期间
     */
    public java.lang.String getPeriod() {
        return period;
    }

    /**
     * 期间
     */
    public void setPeriod(java.lang.String period) {
        this.period = period;
    }
    /**
     * 上期核算期间
     */
    public java.lang.String getLastPeriod() {
        return lastPeriod;
    }

    /**
     * 上期核算期间
     */
    public void setLastPeriod(java.lang.String lastPeriod) {
        this.lastPeriod = lastPeriod;
    }
    /**
     * 上期分摊成本
     */
    public java.math.BigDecimal getLastCostMny() {
        return lastCostMny;
    }

    /**
     * 上期分摊成本
     */
    public void setLastCostMny(java.math.BigDecimal lastCostMny) {
        this.lastCostMny = lastCostMny;
    }
    /**
     * 累计分摊成本
     */
    public java.math.BigDecimal getSumCostMny() {
        return sumCostMny;
    }

    /**
     * 累计分摊成本
     */
    public void setSumCostMny(java.math.BigDecimal sumCostMny) {
        this.sumCostMny = sumCostMny;
    }
    /**
     * 本期分摊成本
     */
    public java.math.BigDecimal getCostMny() {
        return costMny;
    }

    /**
     * 本期分摊成本
     */
    public void setCostMny(java.math.BigDecimal costMny) {
        this.costMny = costMny;
    }
    /**
     * 待分摊成本
     */
    public java.math.BigDecimal getUnCostMny() {
        return unCostMny;
    }

    /**
     * 待分摊成本
     */
    public void setUnCostMny(java.math.BigDecimal unCostMny) {
        this.unCostMny = unCostMny;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}
